dt_cfgs

Function dt_cfgs 

pub fn dt_cfgs()
Generate cfg directives for each of the nodes in the generated device tree.

This assumes that build_dts was already run by the zephyr crate, which should happen if this is called from a user application.