pub fn export_kconfig_bool_options()Expand description
Export boolean Kconfig entries. This must happen in any crate that wishes to access the configuration settings.
pub fn export_kconfig_bool_options()Export boolean Kconfig entries. This must happen in any crate that wishes to access the configuration settings.